@@ -1167,7 +1167,9 @@ static int do_session(
 	stage = STAGE_GETAUTH;
 	if (ctl->server.base_protocol->getauth)
 	{
+	    set_timeout(mytimeout);
 	    err = (ctl->server.base_protocol->getauth)(mailserver_socket, ctl, buf);
+	    set_timeout(0);
 
 	    if (err != 0)
 	    {
@@ -1186,6 +1188,9 @@ static int do_session(
 			   ctl->server.truename,
 			   (ctl->wehaveauthed ? GT_(" (previously authorized)") : "")
 			);
+		    if (ctl->server.authenticate == A_ANY && !ctl->wehaveauthed) {
+			report(stderr, GT_("For help, see http://www.fetchmail.info/fetchmail-FAQ.html#R15\n"));
+		    }
 
 		    /*
 		     * If we're running in background, try to mail the
